tiled.queries.Eq
================

.. currentmodule:: tiled.queries

.. autoclass:: Eq

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Eq.__init__
      ~Eq.decode
      ~Eq.encode
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Eq.key
      ~Eq.value
   
   